import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import DualListSelectCommon from '@data-driven-forms/common/dual-list-select';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import { Grid, Row, Column, Button, FormGroup, Search, StructuredListWrapper, StructuredListRow, StructuredListBody, StructuredListCell, TooltipIcon } from 'carbon-components-react';
import { CheckmarkFilled16, ChevronRight32, ChevronLeft32, CaretSortDown32, CaretSortUp32 } from '@carbon/icons-react';
import { buildLabel } from '../prepare-props';
var useStyles = createUseStyles({
  dualList: {
    maxHeight: 500,
    overflow: 'auto',
    display: 'block',
    marginBottom: 0
  },
  dualListBody: {
    width: '100%',
    display: 'inline-table'
  },
  buttonWrapper: {
    flexDirection: 'column',
    padding: '8px !important',
    paddingTop: '8px !important',
    button: {
      width: '100%',
      maxWidth: '100%',
      '@media (max-width: 1055px)': {
        svg: {
          transform: 'rotate(90deg)'
        }
      }
    },
    '& button:not(:last-child)': {
      marginBottom: 8
    }
  },
  toolbar: {
    display: 'flex'
  },
  tooltipButton: {
    background: '#c2c1c1 !important'
  }
});

var EmptyList = function EmptyList(_ref) {
  var message = _ref.message;
  return /*#__PURE__*/React.createElement(StructuredListWrapper, null, /*#__PURE__*/React.createElement(StructuredListBody, null, /*#__PURE__*/React.createElement(StructuredListRow, null, /*#__PURE__*/React.createElement(StructuredListCell, null, message))));
};

EmptyList.propTypes = {
  message: PropTypes.string
};

var List = function List(_ref2) {
  var options = _ref2.options,
      selectedValues = _ref2.selectedValues,
      handleOptionsClick = _ref2.handleOptionsClick,
      noTitle = _ref2.noTitle,
      ListProps = _ref2.ListProps,
      BodyProps = _ref2.BodyProps;

  var _useStyles = useStyles(),
      dualList = _useStyles.dualList,
      dualListBody = _useStyles.dualListBody;

  return options.length > 0 ? /*#__PURE__*/React.createElement(StructuredListWrapper, _extends({
    selection: true
  }, ListProps, {
    className: clsx(dualList, ListProps.className)
  }), /*#__PURE__*/React.createElement(StructuredListBody, _extends({}, BodyProps, {
    className: clsx(dualListBody, BodyProps.className)
  }), options.map(function (_ref3) {
    var value = _ref3.value,
        label = _ref3.label,
        ListRowProps = _ref3.ListRowProps,
        ListCellProps = _ref3.ListCellProps,
        GridProps = _ref3.GridProps,
        RowProps = _ref3.RowProps,
        LabelProps = _ref3.LabelProps,
        CheckmarkProps = _ref3.CheckmarkProps;
    return /*#__PURE__*/React.createElement(StructuredListRow, _extends({
      key: value
    }, ListRowProps, {
      onClick: function onClick(e) {
        return handleOptionsClick(_objectSpread(_objectSpread({}, e), {}, {
          ctrlKey: true
        }), value);
      }
    }), /*#__PURE__*/React.createElement(StructuredListCell, ListCellProps, /*#__PURE__*/React.createElement(Grid, GridProps, /*#__PURE__*/React.createElement(Row, _extends({
      narrow: true
    }, RowProps), /*#__PURE__*/React.createElement(Column, _extends({
      sm: 3
    }, LabelProps), label), /*#__PURE__*/React.createElement(Column, _extends({
      sm: 1
    }, CheckmarkProps), selectedValues.includes(value) && /*#__PURE__*/React.createElement(CheckmarkFilled16, null))))));
  }))) : /*#__PURE__*/React.createElement(EmptyList, {
    message: noTitle
  });
};

List.propTypes = {
  options: PropTypes.array,
  selectedValues: PropTypes.array,
  handleOptionsClick: PropTypes.func,
  noTitle: PropTypes.node,
  ListProps: PropTypes.object,
  BodyProps: PropTypes.object
};

var Toolbar = function Toolbar(_ref4) {
  var sortTitle = _ref4.sortTitle,
      onFilter = _ref4.onFilter,
      onSort = _ref4.onSort,
      sortDirection = _ref4.sortDirection,
      placeholder = _ref4.placeholder,
      ToolbarProps = _ref4.ToolbarProps,
      SearchProps = _ref4.SearchProps,
      SortProps = _ref4.SortProps;

  var _useStyles2 = useStyles(),
      toolbar = _useStyles2.toolbar,
      tooltipButton = _useStyles2.tooltipButton;

  return /*#__PURE__*/React.createElement("div", _extends({}, ToolbarProps, {
    className: clsx(toolbar, ToolbarProps.className)
  }), /*#__PURE__*/React.createElement(Search, _extends({
    onChange: function onChange(e) {
      return onFilter(e.target.value);
    },
    labelText: "",
    placeholder: placeholder
  }, SearchProps)), /*#__PURE__*/React.createElement(TooltipIcon, _extends({
    onClick: onSort,
    tooltipText: sortTitle
  }, SortProps, {
    className: clsx(tooltipButton, SortProps.className)
  }), sortDirection ? /*#__PURE__*/React.createElement(CaretSortDown32, null) : /*#__PURE__*/React.createElement(CaretSortUp32, null)));
};

Toolbar.propTypes = {
  sortTitle: PropTypes.string,
  onFilter: PropTypes.func,
  onSort: PropTypes.func,
  sortDirection: PropTypes.bool,
  placeholder: PropTypes.string,
  ToolbarProps: PropTypes.object,
  SearchProps: PropTypes.object,
  SortProps: PropTypes.object
};

var isEmpty = function isEmpty(array) {
  return array.length === 0;
};

var DualListSelectInner = function DualListSelectInner(_ref5) {
  var leftValues = _ref5.leftValues,
      handleOptionsClick = _ref5.handleOptionsClick,
      rightValues = _ref5.rightValues,
      handleValuesClick = _ref5.handleValuesClick,
      handleMoveRight = _ref5.handleMoveRight,
      handleClearLeftValues = _ref5.handleClearLeftValues,
      handleMoveLeft = _ref5.handleMoveLeft,
      handleClearRightValues = _ref5.handleClearRightValues,
      state = _ref5.state,
      filterOptions = _ref5.filterOptions,
      filterValues = _ref5.filterValues,
      sortOptions = _ref5.sortOptions,
      sortValues = _ref5.sortValues,
      noOptionsTitle = _ref5.noOptionsTitle,
      noValueTitle = _ref5.noValueTitle,
      leftTitle = _ref5.leftTitle,
      rightTitle = _ref5.rightTitle,
      LeftTitleElement = _ref5.LeftTitleElement,
      RightTitleElement = _ref5.RightTitleElement,
      LeftTitleProps = _ref5.LeftTitleProps,
      RightTitleProps = _ref5.RightTitleProps,
      moveLeftTitle = _ref5.moveLeftTitle,
      moveRightTitle = _ref5.moveRightTitle,
      moveAllLeftTitle = _ref5.moveAllLeftTitle,
      moveAllRightTitle = _ref5.moveAllRightTitle,
      label = _ref5.label,
      isRequired = _ref5.isRequired,
      filterOptionsTitle = _ref5.filterOptionsTitle,
      filterValuesTitle = _ref5.filterValuesTitle,
      sortOptionsTitle = _ref5.sortOptionsTitle,
      sortValuesTitle = _ref5.sortValuesTitle,
      filterOptionsText = _ref5.filterOptionsText,
      filterValueText = _ref5.filterValueText,
      FormGroupProps = _ref5.FormGroupProps,
      GridProps = _ref5.GridProps,
      RowProps = _ref5.RowProps,
      OptionsColumnProps = _ref5.OptionsColumnProps,
      ButtonColumnProps = _ref5.ButtonColumnProps,
      ValuesColumnProps = _ref5.ValuesColumnProps,
      AddButtonProps = _ref5.AddButtonProps,
      AddAllButtonProps = _ref5.AddAllButtonProps,
      RemoveButtonProps = _ref5.RemoveButtonProps,
      RemoveAllButtonProps = _ref5.RemoveAllButtonProps,
      LeftToolbarProps = _ref5.LeftToolbarProps,
      RightToolbarProps = _ref5.RightToolbarProps,
      LeftSearchProps = _ref5.LeftSearchProps,
      RightSearchProps = _ref5.RightSearchProps,
      LeftSortProps = _ref5.LeftSortProps,
      RightSortProps = _ref5.RightSortProps,
      LeftListProps = _ref5.LeftListProps,
      LeftBodyProps = _ref5.LeftBodyProps,
      RightListProps = _ref5.RightListProps,
      RightBodyProps = _ref5.RightBodyProps;

  var _useStyles3 = useStyles(),
      buttonWrapper = _useStyles3.buttonWrapper;

  return /*#__PURE__*/React.createElement(FormGroup, _extends({
    legendText: buildLabel(label || '', isRequired)
  }, FormGroupProps), /*#__PURE__*/React.createElement(Grid, GridProps, /*#__PURE__*/React.createElement(Row, _extends({
    condensed: true
  }, RowProps), /*#__PURE__*/React.createElement(Column, _extends({
    sm: 4,
    md: 8,
    lg: 5
  }, OptionsColumnProps), /*#__PURE__*/React.createElement(LeftTitleElement, LeftTitleProps, leftTitle), /*#__PURE__*/React.createElement(Toolbar, {
    onFilter: filterOptions,
    placeholder: filterOptionsTitle,
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    sortTitle: sortOptionsTitle,
    ToolbarProps: LeftToolbarProps,
    SearchProps: LeftSearchProps,
    SortProps: LeftSortProps
  }), /*#__PURE__*/React.createElement(List, {
    ListProps: LeftListProps,
    BodyProps: LeftBodyProps,
    options: leftValues,
    selectedValues: state.selectedLeftValues,
    handleOptionsClick: handleOptionsClick,
    noTitle: state.filterOptions ? filterOptionsText : noOptionsTitle
  })), /*#__PURE__*/React.createElement(Column, _extends({
    sm: 4,
    md: 8,
    lg: 2
  }, ButtonColumnProps, {
    className: clsx(buttonWrapper, ButtonColumnProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-right",
    renderIcon: ChevronRight32,
    onClick: handleMoveRight,
    disabled: isEmpty(state.selectedLeftValues)
  }, AddButtonProps), moveRightTitle), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-all-right",
    onClick: handleClearLeftValues,
    disabled: isEmpty(leftValues)
  }, AddAllButtonProps), moveAllRightTitle), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-all-left",
    onClick: handleClearRightValues,
    disabled: isEmpty(rightValues)
  }, RemoveAllButtonProps), moveAllLeftTitle), /*#__PURE__*/React.createElement(Button, _extends({
    id: "move-left",
    renderIcon: ChevronLeft32,
    onClick: handleMoveLeft,
    disabled: isEmpty(state.selectedRightValues)
  }, RemoveButtonProps), moveLeftTitle)), /*#__PURE__*/React.createElement(Column, _extends({
    sm: 4,
    md: 8,
    lg: 5
  }, ValuesColumnProps), /*#__PURE__*/React.createElement(RightTitleElement, RightTitleProps, rightTitle), /*#__PURE__*/React.createElement(Toolbar, {
    onFilter: filterValues,
    placeholder: filterValuesTitle,
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    sortTitle: sortValuesTitle,
    ToolbarProps: RightToolbarProps,
    SearchProps: RightSearchProps,
    SortProps: RightSortProps
  }), /*#__PURE__*/React.createElement(List, {
    ListProps: RightListProps,
    BodyProps: RightBodyProps,
    options: rightValues,
    selectedValues: state.selectedRightValues,
    handleOptionsClick: handleValuesClick,
    noTitle: state.filterValue ? filterValueText : noValueTitle
  })))));
};

DualListSelectInner.propTypes = {
  leftValues: PropTypes.array,
  handleOptionsClick: PropTypes.func,
  rightValues: PropTypes.array,
  handleValuesClick: PropTypes.func,
  handleMoveRight: PropTypes.func,
  handleClearLeftValues: PropTypes.func,
  handleMoveLeft: PropTypes.func,
  handleClearRightValues: PropTypes.func,
  state: PropTypes.object,
  filterOptions: PropTypes.func,
  filterValues: PropTypes.func,
  sortValues: PropTypes.func,
  sortOptions: PropTypes.func,
  noOptionsTitle: PropTypes.node,
  noValueTitle: PropTypes.node,
  leftTitle: PropTypes.node,
  rightTitle: PropTypes.node,
  LeftTitleElement: PropTypes.string,
  RightTitleElement: PropTypes.string,
  LeftTitleProps: PropTypes.object,
  RightTitleProps: PropTypes.object,
  moveLeftTitle: PropTypes.node,
  moveRightTitle: PropTypes.node,
  moveAllLeftTitle: PropTypes.node,
  moveAllRightTitle: PropTypes.node,
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  filterOptionsTitle: PropTypes.string,
  filterValuesTitle: PropTypes.string,
  sortOptionsTitle: PropTypes.string,
  sortValuesTitle: PropTypes.string,
  filterOptionsText: PropTypes.node,
  filterValueText: PropTypes.node,
  FormGroupProps: PropTypes.object,
  GridProps: PropTypes.object,
  RowProps: PropTypes.object,
  OptionsColumnProps: PropTypes.object,
  ButtonColumnProps: PropTypes.object,
  ValuesColumnProps: PropTypes.object,
  AddButtonProps: PropTypes.object,
  AddAllButtonProps: PropTypes.object,
  RemoveButtonProps: PropTypes.object,
  RemoveAllButtonProps: PropTypes.object,
  LeftToolbarProps: PropTypes.object,
  RightToolbarProps: PropTypes.object,
  LeftSearchProps: PropTypes.object,
  RightSearchProps: PropTypes.object,
  LeftSortProps: PropTypes.object,
  RightSortProps: PropTypes.object,
  LeftListProps: PropTypes.object,
  LeftBodyProps: PropTypes.object,
  RightListProps: PropTypes.object,
  RightBodyProps: PropTypes.object
};
DualListSelectInner.defaultProps = {
  noOptionsTitle: 'No option available',
  noValueTitle: 'No option selected',
  leftTitle: 'Options',
  rightTitle: 'Selected',
  LeftTitleElement: 'h6',
  RightTitleElement: 'h6',
  moveLeftTitle: 'Remove',
  moveRightTitle: 'Add',
  moveAllLeftTitle: 'Remove All',
  moveAllRightTitle: 'Add All',
  filterOptionsTitle: 'Filter options',
  filterValuesTitle: 'Filter values',
  sortOptionsTitle: 'Sort options',
  sortValuesTitle: 'Sort values',
  filterOptionsText: 'Remove your filter to see all options',
  filterValueText: 'Remove your filter to see all selected',
  FormGroupProps: {},
  GridProps: {},
  RowProps: {},
  OptionsColumnProps: {},
  ButtonColumnProps: {},
  ValuesColumnProps: {},
  AddButtonProps: {},
  AddAllButtonProps: {},
  RemoveButtonProps: {},
  RemoveAllButtonProps: {},
  LeftToolbarProps: {},
  RightToolbarProps: {},
  LeftSearchProps: {},
  RightSearchProps: {},
  LeftSortProps: {},
  RightSortProps: {},
  LeftListProps: {},
  LeftBodyProps: {},
  RightListProps: {},
  RightBodyProps: {}
};

var DualListSelect = function DualListSelect(props) {
  return /*#__PURE__*/React.createElement(DualListSelectCommon, _extends({}, props, {
    DualListSelect: DualListSelectInner
  }));
};

export default DualListSelect;